DENOFO Converter
================

The DENOFO Converter is a tool for converting the **denofo** annotation format
between different file formats (e.g., ``*.dngf`` to ``*.gff`` or ``*.fasta``). 

There are two interfaces for the converter: a command-line interface (CLI) and a
graphical user interface (GUI).

Command-line interface (CLI)
----------------------------

.. automodule:: denofo.converter.converter_cli
    :members:


Graphical user interface (GUI)
------------------------------

.. automodule:: denofo.converter.converter_gui
    :members:


Converter logic implementation
------------------------------

.. automodule:: denofo.converter.convert
    :members:
